@@ -18,7 +18,7 @@ use warnings;
 use constant FOREVER => 9E9;
 use constant LONG_TIME => 9E8;
 
-our $VERSION = '0.83';
+our $VERSION = '0.84';
 
 our $MAIN_PID = $$;
 our $DISABLE_INT = 0;
@@ -191,7 +191,8 @@ sub _child_timeout {
     # we wish to kill not only this child process,
     # but any other active processes that it has spawned.
     # There are several ways to do this.
-    if (Forks::Super::Config::CONFIG('Proc::ProcessTable')) {
+    if (Forks::Super::Config::CONFIG('Proc::ProcessTable') &&
+	$Forks::Super::SysInfo::PROC_PROCESSTABLE_OK) {
 	my @to_kill = 
 	    _child_timeout_read_procs_to_kill_from_Proc_ProcessTable();
 	if (defined $Forks::Super::Job::CHILD_EXEC_PID) {
@@ -215,6 +216,9 @@ sub _child_timeout {
 	$DISABLE_INT = 0;
 
     } elsif (&IS_WIN32) {
+	if ($DEBUG) {
+	    debug("using child_timeout_Win32 to end process");
+	}
 	_child_timeout_Win32();
     }
     if ($DEBUG) {
